summaryrefslogtreecommitdiff
path: root/src/mem/physical.hh
diff options
context:
space:
mode:
Diffstat (limited to 'src/mem/physical.hh')
-rw-r--r--src/mem/physical.hh5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/mem/physical.hh b/src/mem/physical.hh
index 51ec1cbd3..b8d26fd4b 100644
--- a/src/mem/physical.hh
+++ b/src/mem/physical.hh
@@ -75,8 +75,9 @@ class PhysicalMemory : public Serializable
// Global address map
AddrRangeMap<AbstractMemory*> addrMap;
- // a mutable cache for the last range that matched an address
- mutable AddrRange rangeCache;
+ // a mutable cache for the last address map iterator that matched
+ // an address
+ mutable AddrRangeMap<AbstractMemory*>::const_iterator rangeCache;
// All address-mapped memories
std::vector<AbstractMemory*> memories;